---
name: Bug report
about: Create a report to help us improve
title: ''
labels: ''
assignees: ''

---

<!--
Frequently asked questions:
Running SCAT gives ModuleNotFound error? Please install SCAT through pip. Directly running SCAT from the git checkout is not supported.
Running SCAT through sudo gives ModuleNotFound error? Install udev.rules to allow direct USB access as a normal user (recommended) or install SCAT globally.
Looking for Samsung magic value (#27)? Please PM @peremen for the solution.

If your question is none of the above, please delete this comment before writing the bug report.
-->

**SUMMARY**
A clear and concise description of what the bug is.

**STEPS TO REPRODUCE**
Steps to reproduce the behavior:
1. Run SCAT with arguments '...'
2. Trigger '....' on the smartphone or send AT command
3. Wait for '....'
4. See error

**EXPECTED and ACTUAL RESULT**
A clear and concise description of what you expected to happen.

**ENVIRONMENT**
 - OS: [e.g. Linux]
 - SCAT version: [e.g. 1.3.0, git master]
 - Python version: [e.g. 3.9]
 - Cellular device: [e.g. Pixel 6, Quectel RM500Q, Galaxy S22 (SM-S901B)]
 - Baseband type: [Qualcomm, Samsung, UniSOC, HiSilicon]
 - DIAG method: [USB, serial, or baseband dump]

**ADDITIONAL INFORMATION**
Add any other context about the problem here, such as type of cellular network (2G/3G/4G/5G).
